@@ -2,7 +2,7 @@
 Copyright (C) JheysonDev ~ All right reserved
 """
 import os
-from Catsh.utils import Error
+from utils import Error
 
 
 class ExecCommand:
