@@ -1,18 +1,20 @@
 """
 Copyright (C) JheysonDev ~ All right reserved
 """
-from Catsh.commands import Close, Clean, Print, Exec, Env
-from Catsh.utils import Error
+from commands import Close, Clean, Print, Exec, Env
+from utils import Error
 from colorama import Fore
+from config import config
 
 
-class Main:
+class Catsh:
     def __init__(self, prompt="-| "):
         self.prompt = prompt
         self.cli: str = input(self.prompt)
 
     def run(self):
         self.shell()
+        config.run()
 
     def shell(self):
         while self.cli >= "":
@@ -34,6 +36,5 @@ class Main:
             self.cli = input(self.prompt)
 
 
-if __name__ == "__main__":
-    main = Main()
-    run = main.run()
+main = Catsh()
+run = main.run()
